Struct libappindicator_sys::_AppIndicator
source · #[repr(C)]pub struct _AppIndicator {
pub parent: GObject,
pub priv_: *mut AppIndicatorPrivate,
}Expand description
AppIndicator:
A application indicator represents the values that are needed to show a unique status in the panel for an application. In general, applications should try to fit in the other indicators that are available on the panel before using this. But, sometimes it is necissary.
Private fields @parent: Parent object. @priv: Internal data.
Fields
parent: GObjectpriv_: *mut AppIndicatorPrivateTrait Implementations
sourceimpl Clone for _AppIndicator
impl Clone for _AppIndicator
sourcefn clone(&self) -> _AppIndicator
fn clone(&self) -> _AppIndicator
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read more